'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fileSize = _interopDefault(require('filesize'));
var boxen = _interopDefault(require('boxen'));
var Chalk = _interopDefault(require('chalk'));
var deepAssign = _interopDefault(require('deep-assign'));
var gzip = _interopDefault(require('gzip-size'));

var chalk = new Chalk.constructor({ enabled: true });

function filesize() {
	var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

	function render(opt, size, gzip) {
		return opt.theme == 'dark' ? boxen(chalk.green.bold('Bundle size: ') + chalk.yellow.bold(size) + ', ' + chalk.green.bold('Gzipped size: ') + chalk.yellow.bold(gzip), { padding: 1 }) : boxen(chalk.black.bold('Bundle size: ') + chalk.blue.bold(size) + ', ' + chalk.black.bold('Gzipped size: ') + chalk.blue.bold(gzip), { padding: 1 });
	}

	var defaultOptions = {
		format: {},
		theme: 'dark',
		render: render
	};

	var opts = deepAssign({}, defaultOptions, options);
	if (options.render) {
		opts.render = options.render;
	}

	return {
		ongenerate: function ongenerate(bundle, _ref) {
			var code = _ref.code;

			var size = fileSize(Buffer.byteLength(code), opts.format);
			var gzipSize = fileSize(gzip.sync(code), opts.format);

			console.log(opts.render(opts, size, gzipSize));
			return {
				log: opts.render(opts, size, gzipSize),
				code: code,
				map: {
					mappings: ''
				}
			};
		}
	};
};

module.exports = filesize;